﻿using System.Windows;
using System.Windows.Data;

namespace Matarillo
{
    /// <summary>
    /// Silverlight ToolkitのHierarchicalDataTemplateを借用。
    /// </summary>
    public class HierarchicalDataTemplate : DataTemplate
    {
        /// <summary>
        /// データテンプレートのバインディング。データ階層における次の層を表すコレクションを取得する。
        /// </summary>
        /// <remarks>
        ///  デフォルト値はnull。
        /// </remarks>
        public Binding ItemsSource { get; set; }

        #region ItemTemplateプロパティ関係
        /// <summary>
        /// ItemTemplateプロパティの値を入れておくフィールド。
        /// </summary>
        private DataTemplate _itemTemplate;

        /// <summary>
        /// ItemTemplateプロパティが設定されているかを表すプロパティ。
        /// </summary>
        internal bool IsItemTemplateSet { get; private set; }

        /// <summary>
        /// ItemTemplateプロパティ。
        /// データ階層における次の層をどう表示するかを決定する。
        /// </summary>
        public DataTemplate ItemTemplate
        {
            get
            {
                return _itemTemplate;
            }
            set
            {
                IsItemTemplateSet = true;
                _itemTemplate = value;
            }
        }
        #endregion

        #region ItemContainerStyleプロパティ関係
        /// <summary>
        /// ItemContainerStyleプロパティの値を入れておくフィールド。
        /// </summary>
        private Style _itemContainerStyle;

        /// <summary>
        /// ItemContainerStyleプロパティが設定されているかを表すプロパティ。
        /// </summary>
        internal bool IsItemContainerStyleSet { get; private set; }

        /// <summary>
        /// 子要素に適用するスタイルを決定するプロパティ。
        /// </summary>
        public Style ItemContainerStyle
        {
            get
            {
                return _itemContainerStyle;
            }
            set
            {
                IsItemContainerStyleSet = true;
                _itemContainerStyle = value;
            }
        }
        #endregion

        /// <summary>
        /// HierarchicalDataTemplateクラスのインスタンスを初期化。
        /// </summary>
        public HierarchicalDataTemplate()
        {
        }
    }
}
